//-------------------------------------------------------------
// PovRay include file "SkyboxCamera.inc" for skybox camera definitions.
// Defines one of 6 camera directions set by "clock" value.
// Clock values ranging from 0-5 to render all sides:
//  clock |  file
//     0  = _front    +z    Blick nach vorn
//     1  = _right    +x    Blick nach rechts
//     2  = _back     -z    Blick nach hinten
//     3  = _left     -x    Blick nach links
//     4  = _top      +y    Blick nach oben
//     5  = _base     -y    Blick nach unten
// If you include this file you must declare the camera position
// in the Pov-file before!
//   example:  #declare camLoc = <1.1, 2.2, 3.3>;
//-------------------------------------------------------------
camera {
  location <0,0,0>
  angle 90
  right x
  up y
  sky <0,1,0>

  // turns the cam based on the current frame=clock : [0-5]
  #switch (clock)
    #range (0,3)          // 0..3: turn from left to right

      rotate (90*clock)*y
    #break
    #case (4)             // 4: look vertically up

      rotate -90*x
    #break
    #case (5)             // 5: look vertically down

      rotate 89.9999*x
    #break
  #end // end of switch

  translate camLoc       // jump to camera position

} // end include file
